
SoundManager = function(game)
{
    this.game = game;
    try{
        this.soundPlaying = !RUNNING_ON_WP;
        this.musicPlaying = !RUNNING_ON_WP;

        if(localStorage.getItem(GameData.ProfileName + '-sounds'))
            this.soundPlaying = !RUNNING_ON_WP && (JSON.parse(localStorage.getItem(GameData.ProfileName + '-sounds')) === true);
        if(localStorage.getItem(GameData.ProfileName + '-music'))
            this.musicPlaying = !RUNNING_ON_WP && (JSON.parse(localStorage.getItem(GameData.ProfileName + '-music')) === true);
    }catch(e){
        this.soundPlaying = !RUNNING_ON_WP;
        this.musicPlaying = !RUNNING_ON_WP;
    }

    if(GameData.BuildDebug){
        this.musicPlaying = false;
        this.soundPlaying = false;
    }

    this.music = [];
    this.sounds = [];
    this.actualMusic = null;
    this.prevSoundPlayed = null;
}

SoundManager.prototype = {
    constructor: SoundManager,

    create: function ()
    {
        this.addMusic('music_menu', 0.6, true);

        this.addSound('card', 0.2);
        this.addSound('coins', 0.2);
        this.addSound('claim', 0.2);
        this.addSound('redeal', 0.4);
        this.addSound('nomove', 0.2);
        this.addSound('jingle_win', 0.4);
        this.addSound('achieve', 0.4);

        this.addSound('harph0', 0.4);
        this.addSound('harph1', 0.4);
        this.addSound('harph2', 0.4);
        this.addSound('harph3', 0.4);

        this.addSound('dialog', 0.4);
        this.addSound('undo', 0.4);

        this.addSound('tile_wrong-one', 0.4);
        this.addSound('menu-click1', 0.4);
        this.addSound('result_bronze-silver-star', 0.4);
        this.addSound('result_gold-star', 0.4);
    },

    addMusic: function(audioFile, volume, loop)
    {
        if ( loop === undefined )
            loop = false;

        this.music[audioFile] = game.add.audio(audioFile, volume, loop);
    },

    addSound: function(audioFile, volume, loop)
    {
        if ( loop === undefined )
            loop = false;

        this.sounds[audioFile] = game.add.audio(audioFile, volume, loop);
    },

    playMusic: function (musicToPlay, reset)
    {
        if ( reset === undefined )
            reset = false;


        if (musicToPlay != this.actualMusic || reset)
            this.actualMusic = musicToPlay;

        if (!this.musicPlaying)
            return;

        for (var key in this.music){
            if(key == 'contains')
                continue;
            if (key == this.actualMusic)
                this.music[key].play();
            else
                this.music[key].stop();
        }
    },

    playSound: function (soundToPlay)
    {
        if(!this.soundPlaying)
            return;

        try{
            this.sounds[soundToPlay].play();
        }catch(e){
            LOG('Failed to play sound : ' + soundToPlay);
        }
    },

    pauseMusic: function()
    {
        if (!this.musicPlaying)
            return;

        for (var key in this.music){
            if(key == 'contains')
                continue;
            if (key == this.actualMusic)
                this.music[key].pause();
        }
    },

    resumeMusic: function()
    {
        if (!this.musicPlaying)
            return;

        for (var key in this.music){
            if(key == 'contains')
                continue;
            if (key == this.actualMusic)
                this.music[key].resume();
        }
    },

    stopMusic: function ()
    {
        for (var key in this.music){
            if(key == 'contains')
                continue;

            this.music[key].stop();
        }
    },

    toggleMusic: function(musicToPlay)
    {
        if (!this.musicPlaying){
            this.musicPlaying = true;
            this.playMusic(musicToPlay);
        } else {
            this.musicPlaying = false;
            this.stopMusic();
        }
        try{
            localStorage.setItem(GameData.ProfileName + '-music', this.musicPlaying);
        }catch(e){

        }
    },

    toggleSounds: function()
    {
        if (!this.soundPlaying)
            this.soundPlaying = true;
        else{
            this.soundPlaying = false;

            for (var key in this.sounds){
                if(key == 'contains')
                    continue;

                this.sounds[key].stop();
            }
        }
        try{
            localStorage.setItem(GameData.ProfileName + '-sounds', this.soundPlaying);
        }catch(e){

        }
    }


}